documentationtools.Documenter
=============================

.. inheritance-diagram:: abjad.tools.documentationtools.Documenter.Documenter.Documenter
   :private-bases:

.. autoclass:: abjad.tools.documentationtools.Documenter.Documenter.Documenter

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.module_name

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.object

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.prefix

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__call__

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__str__

   .. note:: Inherited from `__builtin__.object`
